@@ -199,6 +199,15 @@ class ShowdownRoster(Roster):
         return self.cached_id
 
 
+class MVPRoster(ShowdownRoster):
+    POSITION_ORDER = {
+        'MVP': 0,
+        'STAR': 1,
+        'PRO': 2,
+        'UTIL': 3,
+    }
+
+
 class NFLRoster(Roster):
     POSITION_ORDER = {
         'QB': 0,
@@ -311,6 +320,8 @@ class RosterSelect:
             'WNBA': WNBARoster(),
             'NFL': NFLRoster(),
             'NFL_SHOWDOWN': ShowdownRoster(),
+            'MLB_MVP': MVPRoster(),
+            'NBA_MVP': MVPRoster(),
             'NFL_MVP': ShowdownRoster(),
             'MLB': MLBRoster(),
             'PGA': PGARoster(),
@@ -441,7 +452,7 @@ class Player(object):
         """
         Used by optimizer to accommodate same player in different positions
         """
-        return '{} {} {}'.format(self.name, self.pos, self.team)
+        return f'{self.name} {self.pos} {self.team}'
 
     @property
     def roster_id(self):
@@ -455,7 +466,7 @@ class Player(object):
     @property
     def formatted_position(self):
         if self.multi_position:
-            return '{} ({})'.format(self.possible_positions, self.pos)
+            return f'{self.possible_positions} ({self.pos})'
         return self.pos
 
     @property
@@ -493,7 +504,7 @@ class Player(object):
         if re.match(r'^[A-Z]{2}$', s[0]):
             return s
 
-        return '{}. {}'.format(s[0][0], s[1])
+        return f'{s[0][0]}. {s[1]}'
 
     def __set_from_data_cache(self, player_data):
         if player_data is None:
@@ -513,7 +524,7 @@ class Game:
         self.opponent = opp
 
     def __repr__(self):
-        return '{} @ {}'.format(self.team, self.opponent)
+        return f'{self.team} @ {self.opponent}'
 
     def team_in_game(self, team):
         return team == self.team or team == self.opponent
